@@ -38,6 +38,7 @@ from duckietown_challenges.utils import tag_from_date
 from . import logger
 from .exceptions import UserError
 from .runner import get_token_from_shell_config, run_single
+from .submission_build import submission_build3
 
 usage = """
 
@@ -64,7 +65,7 @@ def runner_local_main():
         sys.exit(2)
 
 
-def runner_local_main_(args: List[str] = None, token: str = None):
+def runner_local_main_(args: List[str] = None, token: str = None, docker_username: str = "dummy-user"):
     if args is None:
         from duckietown_challenges.col_logging import setup_logging_color
 
@@ -110,6 +111,7 @@ def runner_local_main_(args: List[str] = None, token: str = None):
 
     if token is None:
         token = get_token_from_shell_config()
+
     path = "."
 
     sub_info = read_submission_info(path)
@@ -182,7 +184,7 @@ For example, you could try:
     username = "dummy-org"
     registry = "docker.io"
 
-    solution_container = submission_build_2(username, registry, no_cache)
+    solution_container = submission_build3(username, registry, no_cache)
 
     # image = build_image(
     #     client, tag=tag, path=path, dockerfile=dockerfile, no_cache=no_cache, no_build=no_build,
